@@ -106,7 +106,7 @@ API_BOARD_STATUS_LIST = [
 API_CONTACT_COMMUNICATION_LIST = [
     {
         "id": 2,
-        "contactId": 1,
+        "contactId": 2,
         "type": {
             "id": 2,
             "name": "Direct",
@@ -119,7 +119,7 @@ API_CONTACT_COMMUNICATION_LIST = [
     },
     {
         "id": 3,
-        "contactId": 1,
+        "contactId": 2,
         "type": {
             "id": 1,
             "name": "Email",
@@ -139,12 +139,12 @@ API_COMPANY_CONTACT_LIST = [
         "firstName": "Arnie",
         "lastName": "Bellini",
         "company": {
-            "id": 12,
+            "id": 2,
             "identifier": "YourCompany",
             "name": "TestCompany",
         },
         "site": {
-            "id": 224,
+            "id": 28,
             "name": "Main",
         },
         "inactiveFlag": False,
@@ -161,7 +161,7 @@ API_COMPANY_CONTACT_LIST = [
         "defaultBillingFlag": False,
         "defaultFlag": True,
         "companyLocation": {
-            "id": 2,
+            "id": 1,
             "name": "Tampa Office",
         },
         "communicationItems": API_CONTACT_COMMUNICATION_LIST,
@@ -425,9 +425,12 @@ API_MEMBER = {
     'warehouse': None,
     'warehouseBin': None,
     'workRole': {
-        'id': 11,
-        'name': 'System Engineer',
-        '_info': None
+        'id': API_WORK_ROLE['id'],
+        'name': API_WORK_ROLE['name'],
+        '_info': {
+            'workRole_href':
+                'https://example.com/v4_6_release/test'
+        }
     },
     'workType': None,
     '_info': {
@@ -586,13 +589,7 @@ API_PROJECT = {
     'budgetHours': 91.5,
     'businessUnitId': 10,
     'company': API_COMPANY,
-    'contact': {
-        'id': 70,
-        'name': 'Gregg Kegle',
-        '_info': {
-            'contact_href': 'https://example.com/v4_6_release/apis/3.0/company/contacts/70'
-        }
-    },
+    'contact': None,
     'customerPO': '',
     'description': '\n',
     'currency': {
@@ -664,18 +661,12 @@ API_PROJECT_PHASE = {
     'id': 1,
     'projectId': API_PROJECT['id'],
     'description': 'Project Management',
-    'board': {
-        'id': 3,
-        'name': 'Windows',
-        '_info': {
-            'board_href': 'https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/service/boards/3'
-        }
-    },
+    'board': API_BOARD,
     'status': {
         'id': 1,
         'name': 'Open',
         '_info': {
-            'status_href': 'https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/project/phaseStatuses/1'
+            'status_href': 'https://example.com/v4_6_release/apis/3.0/project/phaseStatuses/1'
         }
     },
     'wbsCode': '1',
@@ -712,7 +703,7 @@ API_PROJECT_PHASE = {
         'isoCode': 'USD',
         'name': 'US Dollars',
         '_info': {
-            'currency_href': 'https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/finance/currencies/7'
+            'currency_href': 'https://example.com/v4_6_release/apis/3.0/finance/currencies/7'
         }
     },
     '_info': {
@@ -903,11 +894,11 @@ API_TYPE = {
         }
     },
     'department': {
-        'id': 13,
-        'identifier': 'Admin',
-        'name': 'Admin',
+        'id': 10,
+        'identifier': "Services",
+        'name': "Professional Services",
         '_info': {
-            'department_href': 'https://example.com/v4_6_release/apis/3.0/system/departments/13'
+            'department_href': "https://example.com/v4_6_release/apis/3.0/system/departments/10"
         }
     },
     '_info': {
@@ -954,7 +945,7 @@ API_ITEM_LIST = [API_ITEM]
 API_TYPE_SUBTYPE_ITEM_ASSOCIATION = {
     "id": 20045,
     "type": {
-        "id": 275,
+        "id": 8,
         "name": "Server",
         "_info": {
             "type_href":
@@ -962,7 +953,7 @@ API_TYPE_SUBTYPE_ITEM_ASSOCIATION = {
         }
     },
     "subType": {
-        "id": 1895,
+        "id": 1,
         "name": "Active Directory",
         "_info": {
             "subType_href":
@@ -970,7 +961,7 @@ API_TYPE_SUBTYPE_ITEM_ASSOCIATION = {
         }
     },
     "item": {
-        "id": 267,
+        "id": 2,
         "name": "Alert",
         "_info": {
             "inactiveFlag": "True",
@@ -979,7 +970,7 @@ API_TYPE_SUBTYPE_ITEM_ASSOCIATION = {
         }
     },
     "board": {
-        "id": 23,
+        "id": 1,
         "name": "Triage Board",
         "_info": {
             "board_href": "https://v4_6_release/apis/3.0/service/boards/23"
@@ -1025,10 +1016,10 @@ API_SERVICE_TICKET = {
     'zip': '33880',
     'country': None,
     'contact': {
-        'id': 70,
-        'name': 'Gregg Kegle',
+        'id': 2,
+        'name': 'Arnie Bellini',
         '_info': {
-            'contact_href': 'https://example.com/v4_6_release/apis/3.0/company/contacts/70'
+            'contact_href': 'https://example.com/v4_6_release/apis/3.0/company/contacts/2'
         }
     },
     'contactName': 'Gregg Kegle',
@@ -1141,21 +1132,21 @@ API_SERVICE_TICKET_MAP = {
 
 
 API_PROJECT_TICKET = {
-    'id': 47,
+    'id': 69,
     'summary': "Senior Engineer Project Planning",
     'isIssueFlag': False,
     'board': {
         'id': API_BOARD['id'],
         'name': API_BOARD['name'],
         '_info': {
-            'board_href': "https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/service/boards/3"
+            'board_href': "https://example.com/v4_6_release/apis/3.0/service/boards/3"
         }
     },
     'status': {
         'id': 1,
         'name': "New",
         '_info': {
-            'status_href': "https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/service/boards/3/statuses/1"
+            'status_href': "https://example.com/v4_6_release/apis/3.0/service/boards/3/statuses/1"
         }
     },
     'project': API_PROJECT,
@@ -1163,7 +1154,7 @@ API_PROJECT_TICKET = {
         'id': API_PROJECT_PHASE['id'],
         'name': API_PROJECT_PHASE['description'],
         '_info': {
-            'phase_href': "https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/project/projects/4/phases/1"
+            'phase_href': "https://example.com/v4_6_release/apis/3.0/project/projects/4/phases/1"
         }
     },
     'wbsCode': "1.1",
@@ -1172,7 +1163,7 @@ API_PROJECT_TICKET = {
         'id': 9,
         'name': "Main",
         '_info': {
-            'site_href': "https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/company/companies/10/sites/9",
+            'site_href': "https://example.com/v4_6_release/apis/3.0/company/companies/10/sites/9",
             'mobileGuid': "7606ac88-1326-4dc6-a620-daf7d9ed3c70"
         }
     },
@@ -1181,11 +1172,11 @@ API_PROJECT_TICKET = {
     'city': "Atlanta",
     'stateIdentifier': "GA",
     'contact': {
-        'id': 26,
-        'name': "Gus Johnson",
+        'id': 2,
+        'name': 'Arnie Bellini',
         '_info': {
             'mobileGuid': "c5221fb2-6d13-4a5b-80a1-c06d714fd93d",
-            'contact_href': "https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/company/contacts/26"
+            'contact_href': "https://example.com/v4_6_release/apis/3.0/company/contacts/26"
         }
     },
     'contactName': "Gus Johnson",
@@ -1204,7 +1195,7 @@ API_PROJECT_TICKET = {
         'id': 2,
         'name': "Phone",
         '_info': {
-            'source_href': "https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/service/sources/2"
+            'source_href': "https://example.com/v4_6_release/apis/3.0/service/sources/2"
         }
     },
     'requiredDate': "2017-03-03T00:00:00Z",
@@ -1230,7 +1221,7 @@ API_PROJECT_TICKET = {
         'id': 2,
         'name': "Tampa Office",
         '_info': {
-            'location_href': "https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/system/locations/2"
+            'location_href': "https://example.com/v4_6_release/apis/3.0/system/locations/2"
         }
     },
     'department': {
@@ -1238,7 +1229,7 @@ API_PROJECT_TICKET = {
         'identifier': "Services",
         'name': "Professional Services",
         '_info': {
-            'department_href': "https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/system/departments/10"
+            'department_href': "https://example.com/v4_6_release/apis/3.0/system/departments/10"
         }
     },
     'mobileGuid': "729d53ab-108e-4fbf-8ed3-5b0a260a8594",
@@ -1248,7 +1239,7 @@ API_PROJECT_TICKET = {
         'isoCode': "USD",
         'name': "US Dollars",
         '_info': {
-            'currency_href': "https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/finance/currencies/7"
+            'currency_href': "https://example.com/v4_6_release/apis/3.0/finance/currencies/7"
         }
     },
     '_info': {
@@ -1430,9 +1421,9 @@ API_SALES_OPPORTUNITY = {
     'closedBy': API_MEMBER,
     'closedDate': '2005-09-09T19:53:52Z',
     'company': API_COMPANY,
-    'contact': {'_info': {'contact_href': 'https://example.com/v4_6_release/apis/3.0/company/contacts/20'},
-                'id': 20,
-                'name': 'Flin Storts'},
+    'contact': {'_info': {'contact_href': 'https://example.com/v4_6_release/apis/3.0/company/contacts/2'},
+                'id': 2,
+                'name': 'Arnie Bellini'},
     "customFields": [
                 {
                     "id": 1,
@@ -1627,10 +1618,10 @@ API_SALES_ACTIVITY = {
     'type': API_SALES_ACTIVITY_TYPES[0],
     'company': API_COMPANY,
     'contact': {
-        'id': 20,
-        'name': 'Flin Storts',
+        'id': 2,
+        'name': 'Arnie Bellini',
         '_info': {
-            'contact_href': 'https://example.com/v4_6_release/apis/3.0/company/contacts/20'
+            'contact_href': 'https://example.com/v4_6_release/apis/3.0/company/contacts/2'
         }
     },
     'phoneNumber': '8139888241',
@@ -1967,7 +1958,7 @@ API_PROJECT_TEAM_MEMBER = {
         'identifier': API_MEMBER['identifier'],
         'name': API_MEMBER['firstName'],
         '_info': {
-            'member_href': 'https://connectwise.kerkhofftech.ca/v4_6_release/apis/3.0/system/members/186' # noqa
+            'member_href': 'https://example.com/v4_6_release/apis/3.0/system/members/186' # noqa
         }
     },
     'projectRole': {
@@ -1984,7 +1975,21 @@ API_PROJECT_TEAM_MEMBER = {
 }
 API_PROJECT_TEAM_MEMBER_LIST = [API_PROJECT_TEAM_MEMBER]
 
-API_COMMUNICATION_TYPE = {
+API_COMMUNICATION_TYPE_LIST = [
+    {
+        "id": 1,
+        "description": "Email",
+        "phoneFlag": True,
+        "faxFlag": False,
+        "emailFlag": False,
+        "defaultFlag": True,
+        "exchangeXref": "Business",
+        "_info": {
+            "lastUpdated": "2003-06-16T19:03:39Z",
+            "dateEntered": "2003-06-16T23:03:39Z",
+        }
+    },
+    {
         "id": 2,
         "description": "Direct",
         "phoneFlag": True,
@@ -1997,5 +2002,4 @@ API_COMMUNICATION_TYPE = {
             "dateEntered": "2003-06-16T23:03:39Z",
         }
     }
-
-API_COMMUNICATION_TYPE_LIST = [API_COMMUNICATION_TYPE]
+]
